<?php

/*******************************************************************************
 * The contents of this file are subject to the following licences:
 * - SugarCRM Public License Version 1.1.2 http://www.sugarcrm.com/SPL
 * - vtiger CRM Public License Version 1.0 
 * You may not use this file except in compliance with the License
 * Software distributed under the License is distributed on an  "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * Portions created by vtiger are Copyright (C) vtiger.
 * Portions created by Vicus are Copyright (C) Vicus.
 * All Rights Reserved.
 * Feel free to use / redistribute these languagefiles under the VPL 1.0.
 * This translations is based on earlier work of: 
 * - IT-Online.nl <www.it-online.nl>
 * - Weltevree.org <www.Weltevree.org>
 ********************************************************************************/

/*******************************************************************************
 * Vicus eBusiness Solutions Version Control
 * @package 	NL-Dutch
 * Description	Dutch language pack for vtiger CRM version 5.3.x
 * @author	$Author: luuk $
 * @version 	$Revision: 1.6 $ $Date: 2012/02/28 23:40:22 $
 * @source	$Source: /var/lib/cvs/vtiger530/Dutch/modules/Users/language/nl_nl.lang.php,v $
 * @copyright	Copyright (c)2005-2011 Vicus eBusiness Solutions bv <info@vicus.nl>
 * @license	vtiger CRM Public License Version 1.0 (by definition)
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Gebruikers',
'LBL_MODULE_TITLE'=>'Gebruikers: Home',
'LBL_SEARCH_FORM_TITLE'=>'Gebruiker zoeken',
'LBL_LIST_FORM_TITLE'=>'Gebruikerslijst',
'LBL_NEW_FORM_TITLE'=>'Nieuwe gebruiker',
'LBL_CREATE_NEW_USER'=>'Maak nieuwe gebruiker aan',
'LBL_LOGIN'=>'Login',
'LBL_USER_ROLE'=>'Rol',
'LBL_LIST_NAME'=>'Naam',
'LBL_LIST_LAST_NAME'=>'Achternaam',
'LBL_LIST_USER_NAME'=>'Gebruikersnaam',
'LBL_LIST_DEPARTMENT'=>'Afdeling',
'LBL_LIST_EMAIL'=>'Email',
'LBL_LIST_PRIMARY_PHONE'=>'Telefoon receptie',
'LBL_LIST_ADMIN'=>'Admin',
'LBL_LIST_CONFIRM_PASSWORD'=>'Bevestig wachtwoord',
'LBL_LIST_USER_NAME_ROLE'=>'Gebruiker ID , naam & rol',
'LBL_LIST_SELECT'=>'Selecteer',
'LBL_LIST_PHONE'=>'Telefoon',
'LBL_LIST_NO'=>'#',

'LBL_ADMINS'=>'Admin',
'LBL_STD_USERS'=>'Standaard gebruikers',

'UserName'=>'Gebruikersnaam',
'Name'=>'Naam',
'Tools'=>'Gereedschap',


//added for patch2
'LBL_GROUP_NAME'=>'Groep',
'LBL_CURRENCY_NAME'=>'Valuta',

'LBL_NEW_USER_BUTTON_TITLE'=>'Nieuwe gebruiker [Alt+N]',
'LBL_NEW_USER_BUTTON_LABEL'=>'Nieuwe gebruiker',
'LBL_NEW_USER_BUTTON_KEY'=>'N',
'LBL_DATE_FORMAT'=>'Datum formaat',

'LBL_ERROR'=>'Fout:',
'LBL_PASSWORD'=>'Wachtwoord:',
'LBL_USER_NAME'=>'Gebruikersnaam',
'LBL_CRM_ID'=>'CRM ID',
'LBL_FIRST_NAME'=>'Voornaam',
'LBL_LAST_NAME'=>'Achternaam',
'LBL_YAHOO_ID'=>'Tweede e-mailadres ',
'LBL_THEME'=>'Thema:',
'LBL_LANGUAGE'=>'Taal:',
'LBL_ADMIN'=>'Admin',
'LBL_OFFICE_PHONE'=>'Telefoon Kantoor',
'LBL_REPORTS_TO'=>'Rapporteert aan',
'LBL_OTHER_PHONE'=>'Telefoon',
'LBL_OTHER_EMAIL'=>'Prive e-mail',
'LBL_DEPARTMENT'=>'Afdeling',
'LBL_STATUS'=>'Status',
'LBL_TITLE'=>'Titel',
'LBL_ANY_PHONE'=>'Telefoon prive:',
'LBL_ANY_EMAIL'=>'Bedrijfs e-mail:',
'LBL_ADDRESS'=>'Straat',
'LBL_CITY'=>'Plaats',
'LBL_STATE'=>'Provincie',
'LBL_POSTAL_CODE'=>'Postcode',
'LBL_COUNTRY'=>'Land',
'LBL_USER_SETTINGS'=>'Gebruikers instellingen',
'LBL_USER_INFORMATION'=>'Gebruikers informatie',
'LBL_MOBILE_PHONE'=>'Telefoon Mobiel',
'LBL_OTHER'=>'Anders',
'LBL_FAX'=>'Fax',
'LBL_EMAIL'=>'E-mail',
'LBL_HOME_PHONE'=>'Telefoon Thuis',
'LBL_ADDRESS_INFORMATION'=>'Adresinformatie',
'LBL_CAL_HRFORMAT'=>'Agenda tijd formaat',
'LBL_CAL_DURATION'=>'Dag begint met',
'LBL_PRIMARY_ADDRESS'=>'Bezoekadres:',

'LBL_CHANGE_PASSWORD_BUTTON_TITLE'=>'Wijzig wachtwoord [Alt+P]',
'LBL_CHANGE_PASSWORD_BUTTON_KEY'=>'P',
'LBL_CHANGE_PASSWORD_BUTTON_LABEL'=>'Wijzig wachtwoord',
'LBL_LOGIN_BUTTON_TITLE'=>'Login [Alt+L]',
'LBL_LOGIN_BUTTON_KEY'=>'L',
'LBL_LOGIN_BUTTON_LABEL'=>'Login',
'LBL_LOGIN_HISTORY_BUTTON_TITLE'=>'Login geschiedenis [Alt+H]',
'LBL_LOGIN_HISTORY_BUTTON_KEY'=>'H',
'LBL_LOGIN_HISTORY_BUTTON_LABEL'=>'Login geschiedenis',
'LBL_LOGIN_HISTORY_TITLE'=>'Gebruikers: Login geschiedenis',
'LBL_RESET_PREFERENCES'=>'Terug naar standaard voorkeuren',

'LBL_CHANGE_PASSWORD'=>'Wijzig wachtwoord',
'LBL_OLD_PASSWORD'=>'Oud wachtwoord:',
'LBL_NEW_PASSWORD'=>'Nieuw wachtwoord:',
'LBL_CONFIRM_PASSWORD'=>'Herhaal wachtwoord:',
'ERR_ENTER_OLD_PASSWORD'=>'Voer uw oude wachtwoord in a.u.b..',
'ERR_ENTER_NEW_PASSWORD'=>'Voer uw nieuwe wachtwoord in a.u.b.',
'ERR_ENTER_CONFIRMATION_PASSWORD'=>'Herhaal uw nieuwe wachtwoord a.u.b.',
'ERR_REENTER_PASSWORDS'=>'Voer uw nieuwe wachtwoord opnieuw in a.u.b.  Uw \"nieuwe wachtwoord\" en \"Herhaal wachtwoord\" zijn niet het zelfde.',
'ERR_INVALID_PASSWORD'=>'U moet wel een geldige gebruikersnaam en wachtwoord invullen.',
'ERR_PASSWORD_CHANGE_FAILED_1'=>'Gebruikers wachtwoord wijziging ging fout omdat ',
'ERR_PASSWORD_CHANGE_FAILED_2'=>' FOUT. Het nieuwe wachtwoord moet opnieuw.',
'ERR_PASSWORD_INCORRECT_OLD'=>'FOUT oude wachtwoord voor gebruiker $this->gebruikersnaam is niet correct. Opnieuw a.u.b..',
'ERR_USER_NAME_EXISTS_1'=>'De gebruikersnaam ',
'ERR_USER_NAME_EXISTS_2'=>' bestaat al. Dubbele gebruikersnamen zijn niet toegestaan.<br>Verander de naam, deze moet uniek zijn.',
'ERR_LAST_ADMIN_1'=>'Gebruikersnaam ',
'ERR_LAST_ADMIN_2'=>' Dit is de laatste admin gebruiker.  Er moet tenminste 1 admin gebruiker zijn.<br>Check de admin instellingen.',

'ERR_DELETE_RECORD'=>"U moet een account selecteren om deze te kunnen verwijderen.",

// Additional Fields for i18n --- Release vtigerCRM 3.2 Patch 2
// Users--listroles.php , createrole.php , ListPermissions.php , editpermissions.php

'LBL_ROLES'=>'Rollen',
'LBL_ROLES_SUBORDINATES'=>'Rollen en medewerkers',

'LBL_CREATE_NEW_ROLE'=>'Maak nieuwe rol',
'LBL_INDICATES_REQUIRED_FIELD'=>'Verplicht veld',
'LBL_NEW_ROLE'=>'Nieuwe rol',
'LBL_PARENT_ROLE'=>'Bijhorende rol',

'LBL_LIST_ROLES'=>'Rollen overzicht',
'LBL_ENTITY_LEVEL_PERMISSIONS'=>'Toestemming entiteit niveau',
'LBL_ENTITY'=>'Entiteit',
'LBL_CREATE_EDIT'=>'Maak',
'LBL_DELETE'=>'Verwijder',
'LBL_LEADS'=>'Leads',
'LBL_ACCOUNTS'=>'Accounts',
'LBL_CONTACTS'=>'Contacten',
'LBL_OPPURTUNITIES'=>'Verkoopkansen',
'LBL_TASKS'=>'Taken',
'LBL_CASES'=>'Zaken',
'LBL_EMAILS'=>'E-mails',
'LBL_NOTES'=>'Notities',
'LBL_MEETINGS'=>'Vergaderingen',
'LBL_CALLS'=>'Telefoongesprekken',
'LBL_IMPORT_PERMISSIONS'=>'Importeer toestemmingen',
'LBL_IMPORT_LEADS'=>'Importeer leads',
'LBL_IMPORT_ACCOUNTS'=>'Importeer accounts',
'LBL_IMPORT_CONTACTS'=>'Importeer contacten',
'LBL_IMPORT_OPPURTUNITIES'=>'Importeer Verkoopkansen',

'LBL_ROLE_DETAILS'=>'Rol details',
//added for vtigercrm4 rc
'LBL_FILE'=> 'Bestandsnaam',
'LBL_FILE_TYPE'=>'Bestandstype',
'LBL_UPLOAD'=>'Upload bestand',
'LBL_ATTACH_FILE'=>'Bijlage e-mail samenvoegen in sjabloon',
'LBL_EMAIL_TEMPLATES'=>'E-mail sjablonen',
'LBL_TEMPLATE_HEADER'=>'Sjabloon',
'LBL_TEMPLATE_DETAILS'=>'Sjabloon details',
'LBL_EDIT_TEMPLATE'=>'Wijzig sjabloon',
'LBL_TEMPLATE_FILE'=>'Sjabloon bestand',
'LBL_EMAIL_TEMPLATES_LIST'=>'Communicatie sjablonen > e-mail sjabloon',
'LBL_MAILMERGE_TEMPLATES_LIST'=>' > Communicatie sjablonen > e-mail samenvoegen met sjabloon',
'LBL_MAILMERGE_TEMPLATES_ATTACHMENT' => '> Communicatie sjablonen > bijlage e-mail samenvoegen in sjabloon',
'LBL_DOWNLOAD_NOW'=>'Nu downloaden',
'LBL_DOWNLOAD'=>'Download',
'LBL_SELECT_MODULE'=>'Selecteer module',
'LBL_MERGE_FILE'=>'Bestand: ',
'LBL_MERGE_MSG'=>'Selecteer een module om sjabloon toe te wijzen',
'LBL_MERGE_FIELDS'=>'Velden samenvoegen',
'LBL_COPY_PASTE'=>'Kopieren & plakken',
'LNK_GO_TO_TOP'=>'Ga naar bovenkant pagina',
'LBL_COLON'=>':',
'LBL_EMAIL_TEMPLATE'=>'E-mail sjabloon',
'LBL_NEW_TEMPLATE'=>'Nieuw sjabloon',
'LBL_ADD_TEMPLATE'=>'Sjabloon toevoegen',
'LBL_USE_MERGE_FIELDS_TO_EMAIL_CONTENT'=>'Gebruik samenvoegen velden om uw e-mail inhoud te personifieren.',
'LBL_AVAILABLE_MERGE_FIELDS'=>'Beschikbare samengevoegde velden',
'LBL_SELECT_FIELD_TYPE'=>'Selecteer veld type',
'LBL_SELECT_FIELD'=>'Selecteer veld:',
'LBL_MERGE_FIELD_VALUE'=>'Kopieer waarde samengevoegde velden:',
'LBL_ACCOUNT_FIELDS'=>'Account velden',
'LBL_CONTACT_FIELDS'=>'Contact velden',
'LBL_LEAD_FIELDS'=>'Lead velden',
'LBL_COPY_AND_PASTE_MERGE_FIELD'=>'Kopieer en plak waarde samengevoegde velden in uw onderstaande sjabloon.',
'LBL_EMAIL_TEMPLATE_INFORMATION'=>'Communicatie sjablonen > e-mail sjabloon > bekijken',
'LBL_FOLDER'=>'Mappen',
'LBL_PERSONAL'=>'Persoonlijk',
'LBL_PUBLIC'=>'Publiek',
'LBL_TEMPLATE_NAME'=>'Naam sjabloon:',
'LBL_SUBJECT'=>'Onderwerp',
'LBL_BODY'=>'E-mail omvang',
'LBL_TEMPLATE_TOOLS'=>'Gereedschap',
'LBL_TEMPLATE_PUBLIC'=>'Toegang publiek',
'LBL_TEMPLATE_PRIVATE'=>'Toegang prive',
'LBL_TEMPLATE_SUBJECT'=>'E-mail onderwerp',
'LBL_TEMPLATE_MESSAGE'=>'E-mail bericht',
'LBL_VIEWING'=>'Bekijken',
'LBL_PROPERTIES'=>'Eigendom van',


//added to fix the issue #6630
'LBL_ASTERISKEXTENSIONS_EXIST' => 'Asterisk Extensie Bestaat Reeds!',

// Added fields in createnewgroup.php
'LBL_CREATE_NEW_GROUP'=>'Maak nieuwe groep',
'LBL_NEW_GROUP'=>'Nieuwe groep',
'LBL_EDIT_GROUP'=>'Bewerk groep',
'LBL_GROUP_NAME'=>'Groepnaam',
'LBL_GROUP_DETAILS'=>'Groep details',
'LBL_MEMBER'=>'Leden',
'LBL_MEMBER_AVLBL'=>'Beschikbare entiteit & leden',
'LBL_MEMBER_SELECTED'=>'Geselecteerde leden',
'LBL_DESCRIPTION'=>'Omschrijving',
'LBL_GROUP_MESG1'=>'Groepen zijn een flexibele manier voor het toekennen van rechten. U kunt verschillende entititeiten verschillende rechten toekennen zoals rollen, gebruikers, profielen enz in een groep.',
'LBL_GROUP_MESG2'=>'Om toe te voegen, selecteer de entiteit leden en klik op ">>".',
'LBL_GROUP_MESG3'=>'Verwijderen, selecteer de groep leden en klik op "<<".',


// Added fields in detailViewmailtemplate.html,listgroupmembers.php,listgroups.php
'LBL_DETAIL_VIEW_OF_EMAIL_TEMPLATE'=>'Bekijk de details van de e-mail sjabloon',
'LBL_DETAIL_VIEW'=>'Bekijk details van',
'LBL_EDIT_VIEW'=>'Verander details van de gebruiker',
'LBL_EDITING'=>'Verander gebruiker',
'LBL_GROUP_MEMBERS_LIST'=>'Groep ledenlijst',
'LBL_GROUPS'=>'Groepen',
'LBL_MY_GROUPS'=>'Mijn groepen',
'LBL_ADD_GROUP_BUTTON'=>'Toevoegen groep',
'LBL_WORD_TEMPLATES'=>'Samenvoegen e-mail sjablonen',
'LBL_NEW_WORD_TEMPLATE'=>'Nieuwe sjabloon',
'LBL_EMAIL_TEMPLATE_DESC'=>'Beheer e-mail sjablonen die u gebruikt voor campagnes en massa mailing',
'LBL_NAME'=>'Naam',

// Added fields in TabCustomise.php,html and UpdateTab.php,html
'LBL_CUSTOMISE_TABS'=>'Verander tabs',
'LBL_CHOOSE_TABS'=>'Kies tabs',
'LBL_AVAILABLE_TABS'=>'Beschikbare tabs',
'LBL_SELECTED_TABS'=>'Geselecteerde tabs',
'LBL_USER'=>'Gebruiker',
'LBL_TAB_MENU_UPDATED'=>'Tab menu bijgewerkt! Graag gaan naar ',
'LBL_TO_VIEW_CHANGES'=>' Laat wijzigingen zien',

// Added to change homepage order
'LBL_CHANGE_HOMEPAGE_LABEL'=>'Homepage volgorde',
'LBL_CHANGE_HOMEPAGE_TITLE'=>'Homepage',

// Added fields in binaryfilelist.php
'LBL_OERATION'=>'Bewerking',

// Added fields in CreateProfile.php
'LBL_PROFILE_NAME'=>'Maak nieuw profiel:',
'LBL_NEW_PROFILE'=>'Nieuw profiel',
'LBL_NEW_PROFILE_NAME'=>'Profielnaam',
'LBL_PARENT_PROFILE'=>'Bijhorende profiel',
'LBL_BASIC_PROFILE_DETAILS'=>'Basis details van het profiel',
'LBL_STEP_1_2'=>'Stap 1 of 2',
'LBL_STEP_2_2'=>'Stap 2 of 2',
'LBL_STEP'=>'Stap',
'LBL_SELECT_BASE_PROFILE'=>'Selecteer basis profiel',
'LBL_PROFILE_PRIVILEGES'=>'Profiel rechten',
'LBL_GLOBAL_PRIVILEGES'=>'Globaal rechten',
'LBL_TAB_PRIVILEGES'=>'Tab rechten',
'LBL_FIELD_PRIVILEGES'=>'Veld rechten',
'LBL_STANDARD_PRIVILEGES'=>'Standaard rechten',
'LBL_UTILITY_PRIVILEGES'=>'Algemene rechten',
'LBL_UTILITIES'=>'Algemene',
'LBL_BASE_PROFILE_MESG'=>'Ik wil een basis profiel maken met verander rechten <b>(Geadviseerd)</b>',
'LBL_BASE_PROFILE'=>'Basis profiel:',
'LBL_OR'=>'of',
'LBL_BASE_PROFILE_MESG_ADV'=>'Ik wil alle rechten verwijderen vanaf het begin <b>(Ervaren Gebruikers)</b>',
'LBL_FOR'=>'voor',
'LBL_GLOBAL_MESG_OPTION'=>'Selecteer opties om de globale rechten te wijzigen',
'LBL_VIEW_ALL'=>'Bekijk alle',
'LBL_EDIT_ALL'=>'Verander alle',
'LBL_ALLOW'=>'Staat toe',
'LBL_MESG_VIEW'=>'Bekijk alle informatie / modules van vTiger CRM',
'LBL_MESG_EDIT'=>'Verander alle informatie / modules van vTiger CRM',
'LBL_STD_MESG_OPTION'=>'Geselecteerde standaard acties zijn toegestaan',
'LBL_TAB_MESG_OPTION'=>'Modules laten zien',
'LBL_UTILITY_MESG_OPTION'=>'Selecteer de mogelijkheid: akties zijn toegestaan',
'LBL_FIELD_MESG_OPTION'=>'Geselecteerde velden zijn toegestaan',
'LBL_FINISH_BUTTON'=>'Klaar',
'LBL_PROFILE_DETAIL_VIEW'=>'Detail: bekijk het profiel',
'LBL_PROFILE_MESG'=>'Bekijk toegangrechten van',
'LBL_PROFILE_M'=>'Profiel',
'LBL_DEFINE_PRIV_FOR'=>' Definieer de rechten van ',
'LBL_USE_OPTION_TO_SET_PRIV'=>'Gebruik de opties om rechten te bepalen',
'LBL_SUPER_USER_PRIV'=>'Super gebruikersrechten',
'LBL_SET_PRIV_FOR_EACH_MODULE'=>'Bepaal rechten voor elke module ',
'LBL_FIELDS_AND_TOOLS_SETTINGS'=>'Velden & Gereedschap instellingen',
'LBL_SHOW_FIELDS'=>'Laat velden zien',
'LBL_TOOLS_TO_BE_SHOWN'=>'Laat gereedschap zien',
'LBL_WELCOME_PROFILE_CREATE'=>'Welkom bij de rechten van de profiel maker ',
'LBL_SELECT_CHOICE_NEW_PROFILE'=>'Selecteer hoe u een nieuw profiel wenst te maken',
'LBL_ADD_CUSTOM_RULE'=>'Toevoegen rechten',
'LBL_EDIT_CUSTOM_RULE'=>'Aanpassen rechten',
'LBL_CLOSE'=>'Sluiten',
'LBL_SELECT_ENTITY'=>'Selecteer een entiteit',
'LBL_CAN_BE_ACCESSED_BY'=>'Toegang voor',
'LBL_PERMISSIONS'=>'Toestemmingen',
'LBL_ACCESS_RIGHTS_FOR_MODULES'=>'Toegangsrechten voor relative modules',
'LBL_RULE_CONSTRUCTION'=>'Regel constructie overzicht',
'LBL_ADD_RULE'=>'Toevoegen regel',
'LBL_RELATED_MODULE_RIGHTS'=>'Gerelateerde module rechten',
'LBL_IN_PERMISSION'=>'Toestemming',

//Added fields in createrole.php
'LBL_HDR_ROLE_NAME'=>'Maak nieuwe rol:',
'LBL_TITLE_ROLE_NAME'=>'Nieuwe rol',
'LBL_ROLE_NAME'=>'Rolnaam',
'LBL_ROLE_PROFILE_NAME'=>'Voeg samen met profiel',
'LBL_SPECIFY_ROLE_NAME'=>'Specificeer een naam voor deze rol :',
'LBL_ASSIGN_PROFILE'=>'Toewijzen profiel(en)',
'LBL_PROFILE_SELECT_TEXT'=>'Selecteer de profielen en klik toewijzen',
'LBL_PROFILES_AVLBL'=>'Beschikbare profielen',
'LBL_ASSIGN_PROFILES'=>'Toegewezen profielen',
'LBL_REPORTS_TO_ROLE'=>'Rapporteert aan rol',
'LBL_ASSOCIATED_PROFILES'=>'Geassocieerde profielen :',
'LBL_ASSOCIATED_USERS'=>'Geassocieerde gebruikers :',


//Added fields in OrgSharingDetailsView.php
'LBL_ORG_SHARING_PRIVILEGES'=>'Organisatie gedeelde rechten',
'LBL_EDIT_PERMISSIONS'=>'Verander toestemmingen',
'LBL_SAVE_PERMISSIONS'=>'Bewaar toestemmingen',
'LBL_READ_ONLY'=>'Publiek: alleen lezen',
'LBL_EDIT_CREATE_ONLY'=>'Publiek: lezen, maak',
'LBL_READ_CREATE_EDIT_DEL'=>'Publiek: lezen, maak, verwijder',
'LBL_PRIVATE'=>'Prive',

//Added fields in listnotificationschedulers.php
'LBL_HDR_EMAIL_SCHDS'=>'Gebruikers : e-mail notificaties',
'LBL_EMAIL_SCHDS_DESC'=>'Hier is de lijst van notificaties die automatisch wordt geactiveerd door de corresponderende afspraak.',
'LBL_ACTIVE'=>'Actief',
'LBL_INACTIVE'=>'Inactief',
'LBL_NOTIFICATION'=>'Notificatie',
'LBL_DESCRIPTION'=>'Omschrijving',
'LBL_TASK_NOTIFICATION'=>'Uitgestelde taak notificatie',
'LBL_TASK_NOTIFICATION_DESCRITPION'=>'Notificatie als een taak langer wordt uitgesteld als 24 uur',
'LBL_MANY_TICKETS'=>'Te veel ticket notificaties',
'LBL_MANY_TICKETS_DESCRIPTION'=>'Laat mij weten als iemand te veel onbehandelde tickets heeft, dit kan service level problemen geven',
'LBL_PENDING_TICKETS'=>'Wacht op ticket notificatie',
'LBL_TICKETS_DESCRIPTION'=>'Laat mij weten als er tickets openstaan met de status wachten',
'LBL_START_NOTIFICATION'=>'Ondersteuning start notificatie',
'LBL_START_DESCRIPTION'=>'Notificatie van de start van Ondersteuning/service',
'LBL_BIG_DEAL'=>'Grote order notificatie',
'LBL_BIG_DEAL_DESCRIPTION'=>'Laat mij weten als een grote order wordt afgesloten',
'LBL_SUPPORT_NOTICIATION'=>'Ondersteuning einde notificatie',
'LBL_SUPPORT_DESCRIPTION'=>'Laat mij weten wanneer Ondersteuning wordt beeindigd',
'LBL_BUTTON_UPDATE'=>'Bijwerken',
'LBL_MODULENAMES'=>'Module',

//Added fields in ListFieldPermissions.html
'LBL_FIELD_PERMISSION_FIELD_NAME'=>'Veldnaam',
'LBL_FIELD_PERMISSION_VISIBLE'=>'Zichtbaar',
'LBL_FIELD_PERMISSIOM_TABLE_HEADER'=>'Standaard velden',
'LBL_FIELD_LEVEL_ACCESS'=>'Toegang veld niveau',

//Added fields after 4.0.1
'LBL_SIGNATURE'=>'Handtekening',

//Added for Event Reminder 4.2 Alpha release
'LBL_ACTIVITY_NOTIFICATION'=>'Afspraak herinner notificatie',
'LBL_ACTIVITY_REMINDER_DESCRIPTION'=>'Laat mij weten als er een afspraak is gemaakt voordat de herinner optie is gepland',
'LBL_MESSAGE'=>'Bericht',

//Added for Global rechten

'Public: Read Only'=>'Publiek: alleen lezen',
'Public: Read, Create/Edit'=>'Publiek: lezen, maak',
'Public: Read, Create/Edit, Delete'=>'Publiek: lezen, maak, verwijder',
'Private'=>'Prive',
'Hide Details'=>'Verberg details',
'Hide Details and Add Events'=>'Verberg details en toevoegen afspraken',
'Show Details'=>'Laat details zien',
'Show Details and Add Events'=>'Laat details zien en toevoegen afspraken',

'LBL_USR_CANNOT_ACCESS'=>'Gebruikers hebben geen toegang tot andere gebruikers',
'LBL_USR_CAN_ACCESS'=>'Gebruikers kunnen ',
'LBL_USR_OTHERS'=>' Andere gebruikers ',

'Read Only '=>'Alleen lezen ',
'Read, Create/Edit, Delete '=>'Lezen, Maak, Verwijder ',
'Read, Create/Edit '=>'Lezen, Maak ',
'Read/Write'=>'Lezen/Schrijf',
'LBL_GO_TO_TOP'=>'Ga naar boven',
'LNK_CLICK_HERE'=>'Klik hier',
'LBL_RULE_NO'=>'Regel nr.',
'LBL_CAN_BE_ACCESSED'=>'Kan opgevraagd worden door',
'LBL_PRIVILEGES'=>'Rechten',
'LBL_OF'=>'of',



//Added for 4.2GA support for mail server integration
'LBL_ADD_MAILSERVER_BUTTON_TITLE'=>'Toevoegen e-mail server',
'LBL_ADD_MAILSERVER_BUTTON_KEY'=>'M',
'LBL_ADD_MAILSERVER_BUTTON_LABEL'=>'Toevoegen e-mail server',

'LBL_LIST_MAILSERVER_BUTTON_TITLE'=>'Lijst e-mail server',
'LBL_LIST_MAILSERVER_BUTTON_KEY'=>'L',
'LBL_LIST_MAILSERVER_BUTTON_LABEL'=>'Lijst e-mail server',
//added for inventory terms and conditions
'INV_TANDC'=>'Algemene Voorwaarden',
'INV_TERMSANDCONDITIONS'=>'Algemene Voorwaarden',
'LBL_INV_TERMSANDCONDITIONS'=>'Voorraad beheer', 


'INVENTORYNOTIFICATION'=>'Voorraad notificaties',
'LBL_INVENTORY_NOTIFICATIONS'=>'Verander voorraad e-mail notificaties',
'LBL_INV_NOT_DESC'=>'De volgende lijst van notificaties wordt naar de product manager gestuurd als de voorraad op het minimum komt.',

'InvoiceNotification'=>'Product voorraad notificatie tijdens het maken van een factuur',
'InvoiceNotificationDescription'=>'Als de voorraad beneden het minimum komt, zal er een notificatie worden verstuurd',

'QuoteNotification'=>'Product voorraad notificatie tijdens het maken van een offerte',
'QuoteNotificationDescription'=>'Product voorraad notificatie tijdens het maken van een offerte als de voorraad minder is dan het minimum.',

'SalesOrderNotification'=>'Product voorraad notificatie tijdens het maken van een verkooporder',
'SalesOrderNotificationDescription'=>'Product voorraad notificatie tijdens het maken van een verkooporder als de voorraad minder is dan het minimum',

//New addition for 4.2 GA
'LBL_USER_FIELDS'=>'Gebruikers velden',
'LBL_NOTE_DO_NOT_REMOVE_INFO'=>'Notitie: De waarden binnen {  } niet veranderen of verwijderen',

//Added for patch2
'LBL_FILE_INFORMATION'=>'Bestand informatiie',

//Added after pathc2
'LBL_LEAD_FIELD_ACCESS'=>'Lead veld toegang',

'LBL_ACCOUNT_FIELD_ACCESS'=>'Account veld toegang',

'LBL_CONTACT_FIELD_ACCESS'=>'Contact veld toegang',

'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Verkoopkans veld toegang',

'LBL_HELPDESK_FIELD_ACCESS'=>'Helpdesk veld toegang',

'LBL_PRODUCT_FIELD_ACCESS'=>'Product veld toegang',

'LBL_NOTE_FIELD_ACCESS'=>'Notitie veld toegang',

'LBL_EMAIL_FIELD_ACCESS'=>'E-mail veld toegang',

'LBL_TASK_FIELD_ACCESS'=>'Taak veld toegang',

'LBL_EVENT_FIELD_ACCESS'=>'Afspraak veld toegang',
'LBL_VENDOR_FIELD_ACCESS'=>'Leverancier veld toegang',
'LBL_PB_FIELD_ACCESS'=>'Prijslijst veld toegang',
'LBL_QUOTE_FIELD_ACCESS'=>'Offerte veld toegang',
'LBL_PO_FIELD_ACCESS'=>'Inkooporder veld toegang',
'LBL_SO_FIELD_ACCESS'=>'Verkooporder toegang',
'LBL_INVOICE_FIELD_ACCESS'=>'Factuur veld toegang',

//given for calendar color for an user user
'LBL_COLOR'=>'Kleur van de agenda',
//added for activity view in home page
'LBL_ACTIVITY_VIEW'=>'Activiteiten overzicht',
//Added to change Home page order
'LBL_HOMEPAGE_ORDER_UPDATE'=>'Vernieuw de blokken volgorde op de Home-pagina',
'LBL_HOMEPAGE_ID'=>'Blok volgorde',
'ERR_INVALID_USER'=>'Geen toegang--probeer via mijn accounts',
'ALVT'=>'Accounts',
'PLVT'=>'Verkoopkansen',
'QLTQ'=>'Offertes',
'CVLVT'=>'Belangrijke gegevens',
'HLT'=>'Helpdesk tickets',
'OLV'=>'Open afspraken',
'GRT'=>'Mijn groep allocatie',
'OLTSO'=>'Verkooporders',
'ILTI'=>'Facturen',
'HDB'=>'Home pagina dashboard',
'OLTPO'=>'Inkooporders',
'LTFAQ'=>'Recente FAQ\'s',
'UA'=>'Activiteiten Aanstaande',
'PA'=>'Activiteiten Wachtend',

//Added for 5.0 alpha
'LBL_GROUP_NAME_ERROR'=>'Groepsnaam bestaat al!',
'MNL'=>'Nieuwe leads',
'LBL_LEAD_VIEW'=>'Standaard lead overzicht',
'LBL_TAG_CLOUD'=>'Koppelingen wolk',
'LBL_LIST_TOOLS'=>'Gereedschap',
'LBL_STATISTICS'=>'Statistieken',
'LBL_TOTAL'=>'Totaal :',
'LBL_OTHERS'=>'Anders :',
'LBL_USERS'=>'Gebruiker(s)',
'LBL_USER_LOGIN_ROLE'=>'Gebruiker login & rol',
'LBL_USER_MORE_INFN'=>'Meer informatie',
'LBL_USER_ADDR_INFN'=>'Adresinformatie',
'LBL_USER_IMAGE'=>'Gebruiker foto',
'LBL_USR'=>'Gebruikers',

'LBL_MY'=>'Mijn',
'LBL_MY_DEFAULTS'=>'Mijn standaard',
'LBL_MY_DESG'=>'Mijn benoeming & contact details',
'LBL_MY_ADDR'=>'Mijn postadres',
'LBL_MY_PHOTO'=>'Mijn foto',
'LBL_CHANGE_PHOTO'=>'Wijzig foto...',
'LBL_CHANGE'=>'Wijzig',


//Added for Access Privileges

'LBL_GLOBAL_FIELDS_MANAGER'=>'Globale velden manager',
'LBL_GLOBAL_ACCESS_PRIVILEGES'=>'Globale toegangsrechten',
'LBL_CUSTOM_ACCESS_PRIVILEGES'=>'Toegangsrechten',
'LBL_BOTH'=>'Allebei',
'LBL_VIEW'=>'Overzicht',
'LBL_RECALCULATE_BUTTON'=>'Herbereken',
'LBL_ADD_PRIVILEGES_BUTTON'=>'Toevoegen rechten',
'LBL_CUSTOM_ACCESS_MESG'=>'Geen toegang regels gedefinieerd .',
'LBL_CREATE_RULE_MESG'=>'Maak een nieuwe regel',
'LBL_SELECT_SCREEN'=>'Selecteer een scherm / module :',
'LBL_FIELDS_AVLBL'=>'Velden beschikbaar in',
'LBL_FIELDS_SELECT_DESELECT'=>'Velden laten zien',
'LBL_ROLE_TO_BE_DELETED'=>'Rol verwijderen',
'LBL_TRANSFER_USER_ROLE'=>'Gebruikers naar rol',
'LBL_DELETE_ROLE'=>'Verwijder rol',
'LBL_MORE_INFORMATION'=>'Meer informatie',
'LBL_USERLOGIN_ROLE'=>'Gebruiker login & rol',
'LBL_USER_IMAGE_INFORMATION'=>'Foto gebruiker',

//Added for 5.0 for all fields
'Role'=>'Rol',
'Email'=>'E-mail',
'Admin'=>'Admin',
'User Name'=>'Gebruikersnaam',
'First Name'=>'Voornaam',
'Last Name'=>'Achternaam',
'Status'=>'Status',
'Default Activity View'=>'Standaard Activiteiten overzicht',
'Default Lead View'=>'Standaard Lead overzicht',
'Currency'=>'Valuta',
'Title'=>'Titel',
'Office Phone'=>'Telefoon Kantoor',
'Department'=>'Afdeling',
'Mobile'=>'Telefoon Mobiel',
'Reports To'=>'Rapporteert aan',
'Other Phone'=>'Telefoon Prive ',
'Other Email'=>'Prive e-mail',
'Fax'=>'Fax',
'Yahoo id'=>'Tweede e-mailadres',
'Home Phone'=>'Thuis telefoon',
'User Image'=>'Foto Gebruiker ',
'Date Format'=>'Datum formaat',
'Tag Cloud'=>'Tag cloud',
'Signature'=>'Handtekening',
'Notes'=>'Notities',
'Documents'=>'Documenten',
'Street Address'=>'Adres',
'City'=>'Plaats',
'State'=>'Provincie',
'Postal Code'=>'Postcode',
'Country'=>'Land',
'Password'=>'Wachtwoord',
'Confirm Password'=>'Bevestig wachtwoord',
'LBL_SHOWN'=>'Gezien',
'LBL_HIDDEN'=>'Verborgen',
'LBL_SHOW'=>'Laten zien',
'LBL_HIDE'=>'Verberg',
'LBL_HOME_PAGE_COMP'=>'Home pagina componenten',
'LBL_LOGIN_HISTORY'=>'Login geschiedenis',
'LBL_USERDETAIL_INFO'=>'Bekijk details van de gebruiker',
'LBL_DELETE_GROUP'=>'Verwijder groep',
'LBL_DELETE_GROUPNAME'=>'Verwijder groep',
'LBL_TRANSFER_GROUP'=>'Verander eigenaar: ',
'LBL_DELETE_USER'=>'Verwijder gebruiker',
'LBL_TRANSFER_USER'=>'Verander eigendom naar gebruiker',
'LBL_DELETE_PROFILE'=>'Verwijder profiel',
'LBL_TRANSFER_ROLES_TO_PROFILE'=>'Verander rol naar profiel',
'LBL_PROFILE_TO_BE_DELETED'=>'Verwijder profiel',

//Added for disabling window Recalculate

'LBL_RECALC_MSG'=>'Weet u zeker dat u gedeelde toegang opnieuw wilt berekenen?',
'LBL_YES'=>'Ja',
'LBL_NO'=>'Nee',

'LBL_MANDATORY_MSG'=>'Verplichte velden',
'LBL_DISABLE_FIELD_MSG'=>'Velden onbruikbaar van Global Field Access Settings',

//Added for About Us

'LBL_CONTACT_US'=>'Contacteer ons',
'LBL_READ_LICENSE'=>'Lees licentie',
'LBL_VERSION'=>'Versie',
'LBL_TEAM'=>'Team',
'LBL_CREDITS'=>'Credits',
'LBL_THIRD_PARTY'=>'Pakket derde partij',
'LBL_COMMUNITY'=>'en vtiger Community',

'LBL_ASSIGN_ROLE'=>'Rol toewijzen',

//Moved from Settings to here for Webmail client integration (for 5.0.3 release)

'LBL_ADD_MAIL_ACCOUNT'=>'Toevoegen e-mail Account',
'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'Nieuwe e-mail Account [Alt+M]',
'LBL_NEW_MAIL_ACCOUNT_KEY'=>'M',
'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'Nieuw e-mail Account',
'LBL_GENERAL_INFO'=>'Algemene informatie',
'LBL_DISPLAY_NAME'=>'Naam tonen',
'LBL_MAIL_PROTOCOL'=>'E-mail Protocol',
'LBL_LIST_PASSWORD'=>'Wachtwoord',
'LBL_MAIL_SERVER_NAME'=>'Email Server Naam of IP',
'LBL_INCOME_SERVER_SETTINGS'=>'Inkomende server',
'LBL_TEST_SETTINGS'=>'Test per direct mijn account instellingen',
'LBL_TEST_BUTTON_TITLE'=>'Test nu mijn account! [Alt+T]',
'LBL_TEST_BUTTON_KEY'=>'T',
'LBL_TEST_BUTTON_LABEL'=>'Test nu mijn account!',
'LBL_DEFAULT'=>'Standaard',
'LBL_IMAP2'=>'IMAP2',
'LBL_IMAP4'=>'IMAP4',
'LBL_POP'=>'POP',
'LBL_IMAP'=>'IMAP',
'LBL_MAIL_DISCLAIM'=>'onderdelen aangeduid met <font color="red">*</font> zijn vereist',
'LBL_SSL_OPTIONS'=>'SSL Opties',
'LBL_TLS'=>'TLS',
'LBL_NO_TLS'=>'No TLS',
'LBL_CERT_VAL'=>'Certificaat bevestiging',
'LBL_INT_MAILER'=>'Gebruik interne mailer?',
'LBL_INT_MAILER_USE'=>'Ja',
'LBL_INT_MAILER_NOUSE'=>'Nee',
'LBL_VAL_SSL_CERT'=>'Bevestig SSL Cert',
'LBL_DONOT_VAL_SSL_CERT'=>'Bevestig niet SSL Cert',
'LBL_WEB_MAIL_CONFIG'=>'Web e-mail configuratie',
'LBL_CONFIGURE_WEB_MAIL'=>' - Configureer web e-mail',
'LBL_LIST_MAIL_ACCOUNT'=>'  Lijst e-mail Account',
'LBL_MY_MAIL_SERVER_DET'=>'Mijn inkomende e-mail server (pop3) details',
'LBL_MY_DETAILS'=>'Mijn details',
'LBL_EMAIL_ID'=>'E-mailadres',
'LBL_EMAIL_ADDRESS'=>'E-mail',
'LBL_NAME_EXAMPLE'=>'(voorbeeld : Luuk Roovers)',
'LBL_EMAIL_EXAMPLE'=>'(voorbeeld : johnfenner@xyz.com)',
'LBL_REFRESH_TIMEOUT'=>'Verversen onderbreken',
'LBL_1_MIN'=>'1 minuut',
'LBL_2_MIN'=>'2 minuten',
'LBL_3_MIN'=>'3 minuten',
'LBL_4_MIN'=>'4 minuten',
'LBL_5_MIN'=>'5 minuten',
'LBL_EMAILS_PER_PAGE'=>'E-mail per pagina',
// Added for 5.0.3

'LBL_ENTER_PROFILE'=>'Geef het profiel op',
'TITLE_USER_DOCUMENT'=>'Document zonder titel',
'TITLE_VTIGER_CRM_5'=>'vtiger CRM 5.1 - gratis, commercieel gekwalificeerd Open Source CRM',
'ROLE_DRAG_ERR_MSG'=>'U kunt geen Ouder Node onderschikken aan een Kind Node',

'LBL_NOTIFICATION_ACTIVITY'=>'Notificatie Activiteit',
'LBL_NOTIFICATION_EMAIL_INFO'=>'Notificatie e-mail Informatie',
'LBL_GOTO_LISTVIEW_BUTTON'=>'Ga naar ListView',
//Added to provide User based TagCloud
'LBL_TAGCLOUD_DISPLAY'=>'Tag Cloud Tonen',
'INTERNAL_MAIL_COMPOSER'=>'Interne Mail-box',

// Added for 5.0.4 to Support Email notication on User Creation
'User Login Details'=>'Gebruikers Login gegevens',
'LBL_TO_LOGIN' => 'om in te loggen',
'LBL_MAIL_SEND_STATUS' => 'Mail verzendstatus:',
'LBL_MAIL_NOT_SENT_TO_USER' => 'Mail kon niet worden verstuurd naar ',
'LBL_PLS_CHECK_EMAIL_N_SERVER' => 'Controleer svp het emailid/Server settings',
// Added/Updated for vtiger CRM 5.0.4

'LBL_SSL' => 'SSL',
//Added to fix the issue #4081
'LBL_USERNAME_EXIST' => 'Een gebruiker met deze naam bestaat al!',
'LBL_UNAUTHORIZED_ACCESS' => 'ongeautoriseerde toegang tot de gebruikersadministratie',
//Added to provide User based TagCloud
'LBL_TAGCLOUD_DISPLAY'=>'Toon Tag Cloud',
'INTERNAL_MAIL_COMPOSER'=>'Interne e-mail Composer',

// Added for 5.0.4 to Support Email notication on User Creation
'User Login Details'=>'Gebruiker Login Details',
'LBL_TO_LOGIN' => 'naar Login',

// Added after 5.0.4 GA

'LBL_USER_ADV_OPTIONS'=>'Geavanceerde gebruikersopties',
'Reminder Interval'=>'herinnerings Interval',
'Webservice Access Key'=>'Toegangssleutel',

//user-group fixes
'LBL_GROUPNAME_EXIST' => 'Een groep met die naam bestaat reeds!',
'LBL_PROFILENAME_EXIST' => 'Een profiel met die naam bestaat reeds!',
//Fixed For Asterisk Configration
'Asterisk Configuration' => 'Asterisk Configuration',
'Asterisk Extension' => 'Asterisk Extension',
' Receive Incoming Calls' => 'Receive Incoming Calls',

// Added for Create Custom Fields 
'LBL_USER_CUSTOMFIELDS_DESCRIPTION' => 'Create Custom Fields for Users ',
'LBL_USER_CUSTOMFIELDS' => 'Gebruikers Eigen velden',

'LBL_CURRENCY_CONFIGURATION'=> 'Currency Configuration',

//Time zones-Dont change any value
'Kwajalein' => '(UTC-12:00) International Date Line West',
'Pacific/Midway' => '(UTC-11:00) Coordinated Universal Time-11',
'Pacific/Samoa' => '(UTC-11:00) Samoa',
'Pacific/Honolulu' => '(UTC-10:00) Hawaii',
'America/Anchorage' => '(UTC-09:00) Alaska',
'America/Los_Angeles' => '(UTC-08:00) Pacific Time (US &amp; Canada)',
'America/Tijuana' => '(UTC-08:00) Tijuana, Baja California',
'America/Denver' => '(UTC-07:00) Mountain Time (US &amp; Canada)',
'America/Chihuahua' => '(UTC-07:00) Chihuahua, La Paz, Mazatlan',
'America/Mazatlan' => '(UTC-07:00) Mazatlan',
'America/Phoenix' => '(UTC-07:00) Arizona',
'America/Regina' => '(UTC-06:00) Saskatchewan',
'America/Tegucigalpa' => '(UTC-06:00) Central America',
'America/Chicago' => '(UTC-06:00) Central Time (US &amp; Canada)',
'America/Mexico_City' => '(UTC-06:00) Mexico City',
'America/Monterrey' => '(UTC-06:00) Monterrey',
'America/New_York' => '(UTC-05:00) Eastern Time (US &amp; Canada)',
'America/Bogota' => '(UTC-05:00) Bogota, Lima, Quito',
'America/Lima' => '(UTC-05:00) Lima',
'America/Rio_Branco' => '(UTC-05:00) Rio Branco',
'America/Indiana/Indianapolis' => '(UTC-05:00) Indiana (East)',
'America/Caracas' => '(UTC-04:30) Caracas',
'America/Halifax' => '(UTC-04:00) Atlantic Time (Canada)',
'America/Manaus' => '(UTC-04:00) Manaus',
'America/Santiago' => '(UTC-04:00) Santiago',
'America/La_Paz' => '(UTC-04:00) La Paz',
'America/Cuiaba' => '(UTC-04:00) Cuiaba',
'America/Asuncion' => '(UTC-04:00) Asuncion',
'America/St_Johns' => '(UTC-03:30) Newfoundland',
'America/Argentina/Buenos_Aires' => '(UTC-03:00) Buenos Aires',
'America/Sao_Paulo' => '(UTC-03:00) Brasilia',
'America/Godthab' => '(UTC-03:00) Greenland',
'America/Montevideo' => '(UTC-03:00) Montevideo',
'Atlantic/South_Georgia' => '(UTC-02:00) Mid-Atlantic',
'Atlantic/Azores' => '(UTC-01:00) Azores',
'Atlantic/Cape_Verde' => '(UTC-01:00) Cape Verde Is.',
'Europe/London' => '(UTC) London, Edinburgh, Dublin, Lisbon',
'UTC' => '(UTC) Coordinated Universal Time, Greenwich Mean Time',
'Africa/Monrovia' => '(UTC) Monrovia, Reykjavik',
'Africa/Casablanca' => '(UTC) Casablanca',
'Europe/Belgrade' => '(UTC+01:00) Belgrade, Bratislava, Budapest, Ljubljana, Prague',
'Europe/Sarajevo' => '(UTC+01:00) Sarajevo, Skopje, Warsaw, Zagreb',
'Europe/Brussels' => '(UTC+01:00) Brussels, Copenhagen, Madrid, Paris',
'Africa/Algiers' => '(UTC+01:00) West Central Africa',
'Europe/Amsterdam' => '(UTC+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Vienna',
'Europe/Minsk' => '(UTC+02:00) Minsk',
'Africa/Cairo' => '(UTC+02:00) Cairo',
'Europe/Helsinki' => '(UTC+02:00) Helsinki, Riga, Sofia, Tallinn, Vilnius',
'Europe/Athens' => '(UTC+02:00) Athens, Bucharest',
'Europe/Istanbul' => '(UTC+02:00) Istanbul',
'Asia/Jerusalem' => '(UTC+02:00) Jerusalem',
'Asia/Amman' => '(UTC+02:00) Amman',
'Asia/Beirut' => '(UTC+02:00) Beirut',
'Africa/Windhoek' => '(UTC+02:00) Windhoek',
'Africa/Harare' => '(UTC+02:00) Harare',
'Asia/Kuwait' => '(UTC+03:00) Kuwait, Riyadh',
'Asia/Baghdad' => '(UTC+03:00) Baghdad',
'Africa/Nairobi' => '(UTC+03:00) Nairobi',
'Asia/Tehran' => '(UTC+03:30) Tehran',
'Asia/Tbilisi' => '(UTC+04:00) Tbilisi',
'Europe/Moscow' => '(UTC+04:00) Moscow, Volgograd',
'Asia/Muscat' => '(UTC+04:00) Abu Dhabi, Muscat',
'Asia/Baku' => '(UTC+04:00) Baku',
'Asia/Yerevan' => '(UTC+04:00) Yerevan',
'Asia/Karachi' => '(UTC+05:00) Islamabad, Karachi',
'Asia/Tashkent' => '(UTC+05:00) Tashkent',
'Asia/Kolkata' => '(UTC+05:30) Chennai, Kolkata, Mumbai, New Delhi',
'Asia/Colombo' => '(UTC+05:30) Sri Jayawardenepura',
'Asia/Katmandu' => '(UTC+05:45) Kathmandu',
'Asia/Dhaka' => '(UTC+06:00) Dhaka',
'Asia/Almaty' => '(UTC+06:00) Almaty',
'Asia/Yekaterinburg' => '(UTC+06:00) Ekaterinburg',
'Asia/Rangoon' => '(UTC+06:30) Yangon (Rangoon)',
'Asia/Novosibirsk' => '(UTC+07:00) Novosibirsk',
'Asia/Bangkok' => '(UTC+07:00) Bangkok, Jakarta',
'Asia/Brunei' => '(UTC+08:00) Beijing, Chongqing, Hong Kong, Urumqi',
'Asia/Krasnoyarsk' => '(UTC+08:00) Krasnoyarsk',
'Asia/Ulaanbaatar' => '(UTC+08:00) Ulaan Bataar',
'Asia/Kuala_Lumpur' => '(UTC+08:00) Kuala Lumpur, Singapore',
'Asia/Taipei' => '(UTC+08:00) Taipei',
'Australia/Perth' => '(UTC+08:00) Perth',
'Asia/Irkutsk' => '(UTC+09:00) Irkutsk',
'Asia/Seoul' => '(UTC+09:00) Seoul',
'Asia/Tokyo' => '(UTC+09:00) Tokyo',
'Australia/Darwin' => '(UTC+09:30) Darwin',
'Australia/Adelaide' => '(UTC+09:30) Adelaide',
'Australia/Canberra' => '(UTC+10:00) Canberra, Melbourne, Sydney',
'Australia/Brisbane' => '(UTC+10:00) Brisbane',
'Australia/Hobart' => '(UTC+10:00) Hobart',
'Asia/Vladivostok' => '(UTC+10:00) Vladivostok',
'Pacific/Guam' => '(UTC+10:00) Guam, Port Moresby',
'Asia/Yakutsk' => '(UTC+10:00) Yakutsk',
'Pacific/Fiji' => '(UTC+12:00) Fiji',
'Asia/Kamchatka' => '(UTC+12:00) Kamchatka',
'Pacific/Auckland' => '(UTC+12:00) Auckland',
'Asia/Magadan' => '(UTC+12:00) Magadan',
'Pacific/Tongatapu' => '(UTC+13:00) Nukualofa',

'Theme'=>'Thema',
'Language'=>'Taal',
'Secondary Email'=>'Tweede E-mail',
'Time Zone'=>'Tijdzone',
);

?>